@@ -33,8 +33,11 @@ from colabo_flow.s_go.vos import (
 	IColaboFlowGoMsgExtension_TaskExecute_Progress,
 	IColaboFlowGoMsgExtension_TaskExecute_Response
 )
+
+from colabo_flow.s_go.executor_vos import ITaskExecutor, IExecutorImplementationReference, IFlowTask, EFlowTaskType, EExecutingEnvironment, IExecutorReference
+
+
 from colabo_flow.s_go.operators import createGoMsg
-from colabo_flow.s_go.executor_vos import ITaskExecutor, IFlowTask
 from colabo_flow.s_go.executor_operators import createTaskInstanceForTaskWithoutFlow
 
 from colabo_flow.s_go.concurrency import run_async_func_under_thread, async_connection_callback_threadsafe
@@ -49,10 +52,60 @@ def host_registerTask(host: IColaboFlowHostData, task: IFlowTask):
 def getTaskExecutor(host: IColaboFlowHostData, executorId: str) -> ITaskExecutor:
 	return host.taskExecutorsAvailable[executorId]
 
+from datetime import datetime
+
+def addOmnipresentTasks(host: IColaboFlowHostData):
+	async def asyncExecutor_echoPing(inputAny: Any) -> Any:
+		if not inputAny:
+			print(f"[asyncExecutor_executeBar] Missing input")
+			return -1
+
+		print(f"[echoPing] Pinged with the input: : {input}")
+		current_date = datetime.now()
+		print()
+
+		output = {
+			"input": inputAny,
+			# https://docs.python.org/3/library/time.html#time.process_time
+			"timeNoSleep": time.process_time(), 
+			# https://docs.python.org/3/library/time.html#time.perf_counter
+			"timePerformance": time.perf_counter(),
+			"timeHuman": current_date.isoformat(),
+			"hostname": host.hostName,
+			"queueHost": host.queueHost
+		};
+
+		return output;
+
+	executorEchoPing: ITaskExecutor = ITaskExecutor(
+		id = "colabo.flow.echoPing",
+		description = "(Python) Used for testing worker availability. Returns the sender message in addition with the local metadata",
+		# TODO: In future it should be isomorphic-like: should work on frontend if provided, on backend if provided (with CLI flow overview), or isomorphic if nothing provide
+		environment = EExecutingEnvironment.BACKEND,
+		reference = IExecutorImplementationReference(
+			async_method = asyncExecutor_echoPing,
+		),
+	)
+
+	taskEchoPing: IFlowTask = IFlowTask(
+		id = "colabo.flow.echoPing",
+		type = EFlowTaskType.SCRIPT,
+		description = "(Python) Used for testing worker availability. Returns the sender message in addition with the local metadata",
+		executorRef = IExecutorReference(
+			id = executorEchoPing.id,
+			environment = EExecutingEnvironment.BACKEND,
+		),
+	)
+
+	host_registerTaskExecutor(host, executorEchoPing);
+	host_registerTask(host, taskEchoPing);
+
 async def host_run(host: IColaboFlowHostData):
 	proc_title = f"ColaboFlow.Go.Host-{host.hostName}"
 	setproctitle(proc_title)
 
+	addOmnipresentTasks(host)
+
 	connect(host)
 	start_consuming(host)
 
@@ -343,17 +396,14 @@ def sendHeartbeatToHost(host: IColaboFlowHostData):
 	heartbeat.msg = f"node host with tasks: {json.dumps(list(host.taskExecutorsAvailable.keys()))}",
 	host.heartbeatId = host.heartbeatId + 1
 
-	if host.reportsConfig.showHeartbeatMsgs:
-		print(f'{host.appNameTextWithContext("sendHeartbeatToHost")} Sending heartbeat [from: "{host.hostName}", queue: "{chalk.blue_bright(host.queueHostHeartbeat)}"]')
-		# print(f"{host.appNameTextWithContext('sendHeartbeatToHost')} Sending heartbeat [queue: '{chalk.blue_bright(host.queueHostHeartbeat)}']: {json.dumps(heartbeat.to_json())}")
-
 	# host.chHostHeartbeat.basic_publish(exchange='', routing_key=host.queueHostHeartbeat, body=heartbeat.to_json())
 	# host.connection.add_callback_threadsafe(
 		# functools.partial(host.chHostHeartbeat.basic_publish, exchange='', routing_key=host.queueHostHeartbeat, body=heartbeat.to_json()))
 	host.connection.add_callback_threadsafe(lambda: _sendHeartbeatToHost(host, heartbeat))
 
 def _sendHeartbeatToHost(host: IColaboFlowHostData, heartbeat: IColaboFlowGoMsg):
-	if host.reportsConfig.showHeartbeatMsgs:
+	# report every `host.reportsConfig.showHeartbeatMsgs`-th message
+	if host.reportsConfig.showHeartbeatMsgs and (heartbeat.extension["id"] % host.reportsConfig.showHeartbeatMsgs == 0):
 		print(f'{host.appNameTextWithContext("_sendHeartbeatToHost")} Sending heartbeat [queue: "{chalk.blue_bright(host.queueHostHeartbeat)}"]: {heartbeat.extension["id"]}')
 		# print(f"{host.appNameTextWithContext('_sendHeartbeatToHost')} Sending heartbeat [queue: '{chalk.blue_bright(host.queueHostHeartbeat)}']: {json.dumps(heartbeat.to_json())}")
 	host.chHostHeartbeat.basic_publish(exchange='', routing_key=host.queueHostHeartbeat, body=heartbeat.to_json())
